==> haskell-htf-0.15.0.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-E21HsBmZQ4iKSyLy27MeK4
key:                  HTF-0.15.0.1-E21HsBmZQ4iKSyLy27MeK4
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  7884d8b307ba5bb51e58ead389dbecf9
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-E21HsBmZQ4iKSyLy27MeK4
depends:
    Diff-0.4.1-B9thiVs2y2uAiqx3tkly0v
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-2FUI0ycZlrbG7BkVMiUKvc
    aeson-2.1.2.1-3hy4hA3togDsVnwRqQAZI array-0.5.4.0 base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    bytestring-0.11.4.0 containers-0.6.5.1
    cpphs-1.20.9.1-1K2ccivGg76HqdQttHm61m directory-1.3.6.2
    haskell-src-1.0.4-FacRhZlaPqE70Ucc0UYsyy
    lifted-base-0.2.3.12-E3byI5R2ZjdBBfIEgy1VPo
    monad-control-1.0.3.1-AX02qra1qxmHNghOyTYjz4 mtl-2.2.2
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy text-1.2.5.0
    time-1.11.1.1 unix-2.7.2.2 vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    xmlgen-0.6.2.2-8C3KTIazQSEP17RrhPujz

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.1
visibility:           public
id:                   HTF-0.15.0.1-LQcFVUFCJQjKhmI1i2Y1pq
key:                  HTF-0.15.0.1-LQcFVUFCJQjKhmI1i2Y1pq
license:              LGPL-2.1-only
copyright:            (c) 2005-2023 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  7abc59d610e53eb24bf3e17f15ae9260
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HTF-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.1-LQcFVUFCJQjKhmI1i2Y1pq
depends:
    Diff-0.4.1-7DJ54PO7amxJCKVFCJguu4
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-8QSIOMYs5brCg5V5nmVdY2
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9 array-0.5.4.0 base-4.16.4.0
    base64-bytestring-1.2.1.0-IROdBrGh8de3SyeGv4rKYj
    bytestring-0.11.4.0 containers-0.6.5.1
    cpphs-1.20.9.1-1K2ccivGg76HqdQttHm61m directory-1.3.6.2
    haskell-src-1.0.4-KLxZrRUOGfLEOosFRFUZMG
    lifted-base-0.2.3.12-BfHq7QxWowU9Ryh2JGHIzd
    monad-control-1.0.3.1-I5AaRJoHRj29hWCKJMaDiM mtl-2.2.2
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-LilJ2o1ueBgJ3oDFJkkk0o
    regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy text-1.2.5.0
    time-1.11.1.1 unix-2.7.2.2 vector-0.13.1.0-1Hbj4hORR7KGMeSpv0BhQN
    xmlgen-0.6.2.2-7IsqOgHSDxzAU8aOGdFCHh

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
